.. _ref-workflows:

=================
Horizon Workflows
=================

.. module:: horizon.workflows

One of the most challenging aspects of building a compelling user experience
is crafting complex multi-part workflows. Horizon's ``workflows`` module
aims to bring that capability within everyday reach.

.. seealso::

   For usage information, tips & tricks and more examples check out the
   :ref:`topics-workflows`.

Workflows
=========

.. autoclass:: Workflow
    :members:

Steps
=====

.. autoclass:: Step
    :members:

Actions
=======

.. autoclass:: Action
    :members:

WorkflowView
============

.. autoclass:: WorkflowView
    :members:
